@@ -11,14 +11,18 @@ from tqdm import tqdm
 from .logger import logger
 
 
-def submit_task(func, item, use_kwargs=False):
+def submit_task(func, item, unpack_args=False, unpack_kwargs=False):
     """根据item的类型决定如何调用函数
     
     Args:
         func: 要执行的函数
         item: 输入项
-        use_kwargs: 当item是字典时，是否按关键字参数传递（True）；
-            为 False 时将字典整体作为一个位置参数传递
+        unpack_args: 控制元组/列表的传递方式。
+            - True: 解包为位置参数传递
+            - False: 整体作为单个位置参数传递（默认）
+        unpack_kwargs: 控制字典的传递方式。
+            - True: 解包为关键字参数传递
+            - False: 整体作为单个位置参数传递（默认）
     """
     if isinstance(item, dict):
         # 检查是否是混合格式 {'args': (...), 'kwargs': {...}}
@@ -30,22 +34,27 @@ def submit_task(func, item, use_kwargs=False):
             return func(**item["kwargs"])
         else:
             # 纯字典
-            if use_kwargs:
+            if unpack_kwargs:
                 # 作为关键字参数传递
                 return func(**item)
             else:
                 # 将字典整体作为单个位置参数传递
                 return func(item)
     elif isinstance(item, (tuple, list)) and not isinstance(item, str):
-        # 元组或列表，作为位置参数
-        return func(*item)
+        # 元组或列表
+        if unpack_args:
+            # 作为位置参数传递
+            return func(*item)
+        else:
+            # 将元组或列表整体作为单个位置参数传递
+            return func(item)
     else:
         # 单个值
         return func(item)
 
 
 def sequential_map(
-    func, items, description=None, log_level="none", progress_type="rich", use_kwargs=False
+    func, items, description=None, log_level="none", progress_type="rich", unpack_args=False, unpack_kwargs=False, raise_on_error=False, error_return_value=None
 ):
     """
     顺序执行函数，用于单线程场景（如调试）
@@ -59,11 +68,25 @@ def sequential_map(
             - "rich": 使用 rich 进度条（默认）
             - "tqdm": 使用 tqdm 进度条
             - "none": 无进度条
-        use_kwargs: 当items中的元素是字典时，是否按关键字参数传递（True）；
-            为 False 时将字典整体作为一个位置参数传递
+        unpack_args: 控制元组/列表的传递方式。
+            - True: 解包为位置参数传递
+            - False: 整体作为单个位置参数传递（默认）
+        unpack_kwargs: 控制字典的传递方式。
+            - True: 解包为关键字参数传递
+            - False: 整体作为单个位置参数传递（默认）
+        raise_on_error: 控制错误处理方式。
+            - True: 遇到错误时立即抛出异常
+            - False: 将异常对象添加到结果列表中（默认）
+        error_return_value: 当 raise_on_error=False 时，出错时返回的指定值。
+            - None: 返回 None（默认）
+            - "error_log": 返回错误信息字符串
+            - 其他值: 返回指定的值
 
     Returns:
         按输入顺序排列的结果列表
+
+    Raises:
+        Exception: 当 raise_on_error=True 且函数执行出错时抛出异常
     """
     results = []
 
@@ -92,12 +115,17 @@ def sequential_map(
             total_task = progress.add_task(f"[green]{description}[/green]", total=total)
             for i, item in enumerate(items):
                 try:
-                    result = submit_task(func, item, use_kwargs)
+                    result = submit_task(func, item, unpack_args, unpack_kwargs)
                     logger.log(log_level, f"index: {i}, result: {result}")
                     results.append(result)
                 except Exception as e:
                     logger.error(f"Error in sequential_map: {e}")
-                    results.append(e)
+                    if raise_on_error:
+                        raise
+                    if error_return_value == "error_log":
+                        results.append(str(e))
+                    else:
+                        results.append(error_return_value)
                 progress.update(total_task, advance=1)
 
     elif progress_type == "tqdm":
@@ -105,30 +133,40 @@ def sequential_map(
         with tqdm(total=total, desc=description, unit="item") as pbar:
             for i, item in enumerate(items):
                 try:
-                    result = submit_task(func, item, use_kwargs)
+                    result = submit_task(func, item, unpack_args, unpack_kwargs)
                     logger.log(log_level, f"index: {i}, result: {result}")
                     results.append(result)
                 except Exception as e:
                     logger.error(f"Error in sequential_map: {e}")
-                    results.append(e)
+                    if raise_on_error:
+                        raise
+                    if error_return_value == "error_log":
+                        results.append(str(e))
+                    else:
+                        results.append(error_return_value)
                 pbar.update(1)
 
     else:  # progress_type == "none"
         # 无进度条
         for i, item in enumerate(items):
             try:
-                result = submit_task(func, item, use_kwargs)
+                result = submit_task(func, item, unpack_args, unpack_kwargs)
                 logger.log(log_level, f"index: {i}, result: {result}")
                 results.append(result)
             except Exception as e:
                 logger.error(f"Error in sequential_map: {e}")
-                results.append(e)
+                if raise_on_error:
+                    raise
+                if error_return_value == "error_log":
+                    results.append(str(e))
+                else:
+                    results.append(error_return_value)
 
     return results
 
 
 def parallel_map(
-    func, items, description=None, log_level="none", max_workers=5, progress_type="rich", use_kwargs=False
+    func, items, description=None, log_level="none", max_workers=5, progress_type="rich", unpack_args=False, unpack_kwargs=False, raise_on_error=False, error_return_value=None
 ):
     """
     并行执行函数，保证输出顺序与输入顺序一致
@@ -147,12 +185,26 @@ def parallel_map(
             - "rich": 使用 rich 进度条（默认）
             - "tqdm": 使用 tqdm 进度条
             - "none": 无进度条
-        use_kwargs: 当items中的元素是字典时，是否按关键字参数传递（True）；
-            为 False 时将字典整体作为一个位置参数传递
+        unpack_args: 控制元组/列表的传递方式。
+            - True: 解包为位置参数传递
+            - False: 整体作为单个位置参数传递（默认）
+        unpack_kwargs: 控制字典的传递方式。
+            - True: 解包为关键字参数传递
+            - False: 整体作为单个位置参数传递（默认）
+        raise_on_error: 控制错误处理方式。
+            - True: 遇到错误时立即抛出异常
+            - False: 将异常对象添加到结果列表中（默认）
+        error_return_value: 当 raise_on_error=False 时，出错时返回的指定值。
+            - None: 返回 None（默认）
+            - "error_log": 返回错误信息字符串
+            - 其他值: 返回指定的值
 
     Returns:
         按输入顺序排列的结果列表
 
+    Raises:
+        Exception: 当 raise_on_error=True 且函数执行出错时抛出异常
+
     Examples:
         # 单个参数
         parallel_map(lambda x: x * 2, [1, 2, 3])
@@ -164,7 +216,7 @@ def parallel_map(
         parallel_map(lambda a, b: a + b, [{'a': 1, 'b': 2}, {'a': 3, 'b': 4}])
 
         # 字典作为单个位置参数（适用于形参是一个dict的函数）
-        parallel_map(lambda d: (d['a'] + d['b']), [{'a': 1, 'b': 2}, {'a': 3, 'b': 4}], use_kwargs=False)
+        parallel_map(lambda d: (d['a'] + d['b']), [{'a': 1, 'b': 2}, {'a': 3, 'b': 4}], unpack_kwargs=False)
 
         # 混合参数
         parallel_map(lambda x, y, z=0: x + y + z,
@@ -182,7 +234,7 @@ def parallel_map(
     """
     # 如果只有一个worker或更少，使用顺序执行，避免线程开销
     if max_workers <= 1:
-        return sequential_map(func, items, description, log_level, progress_type, use_kwargs)
+        return sequential_map(func, items, description, log_level, progress_type, unpack_args, unpack_kwargs, raise_on_error, error_return_value)
 
     # 检查是否支持len，如果不支持则转换为列表
     if not hasattr(items, "__len__"):
@@ -196,9 +248,9 @@ def parallel_map(
 
     results = [None] * len(items)
     
-    # 创建包装函数来传递 use_kwargs 参数
+    # 创建包装函数来传递 unpack_kwargs 参数
     def submit_task_wrapper(func, item):
-        return submit_task(func, item, use_kwargs)
+        return submit_task(func, item, unpack_args, unpack_kwargs)
 
     if progress_type == "rich":
         # 使用 rich 进度条，显示数量和进度
@@ -231,7 +283,12 @@ def parallel_map(
                         results[index] = future.result()
                     except Exception as e:
                         logger.error(f"Error in parallel_map: {e}")
-                        results[index] = e
+                        if raise_on_error:
+                            raise
+                        if error_return_value == "error_log":
+                            results[index] = str(e)
+                        else:
+                            results[index] = error_return_value
                     progress.update(total_task, advance=1)
 
     elif progress_type == "tqdm":
@@ -258,7 +315,12 @@ def parallel_map(
                             results[index] = future.result()
                         except Exception as e:
                             logger.error(f"Error in parallel_map: {e}")
-                            results[index] = e
+                            if raise_on_error:
+                                raise
+                            if error_return_value == "error_log":
+                                results[index] = str(e)
+                            else:
+                                results[index] = error_return_value
                         pbar.update(1)
 
     else:  # progress_type == "none"
@@ -278,13 +340,18 @@ def parallel_map(
                     results[index] = future.result()
                 except Exception as e:
                     logger.error(f"Error in parallel_map: {e}")
-                    results[index] = e
+                    if raise_on_error:
+                        raise
+                    if error_return_value == "error_log":
+                        results[index] = str(e)
+                    else:
+                        results[index] = error_return_value
 
     return results
 
 
 def auto_map(
-    func, items, description=None, log_level="none", max_workers=1, progress_type="rich", use_kwargs=False
+    func, items, description=None, log_level="none", max_workers=1, progress_type="rich", unpack_args=False, unpack_kwargs=False, raise_on_error=False, error_return_value=None
 ):
     """
     智能映射函数，根据max_workers自动选择执行方式
@@ -299,10 +366,24 @@ def auto_map(
             - "rich": 使用 rich 进度条（默认）
             - "tqdm": 使用 tqdm 进度条
             - "none": 无进度条
-        use_kwargs: 当items中的元素是字典时，是否按关键字参数传递（True）；
-            为 False 时将字典整体作为一个位置参数传递
+        unpack_args: 控制元组/列表的传递方式。
+            - True: 解包为位置参数传递
+            - False: 整体作为单个位置参数传递（默认）
+        unpack_kwargs: 控制字典的传递方式。
+            - True: 解包为关键字参数传递
+            - False: 整体作为单个位置参数传递（默认）
+        raise_on_error: 控制错误处理方式。
+            - True: 遇到错误时立即抛出异常
+            - False: 将异常对象添加到结果列表中（默认）
+        error_return_value: 当 raise_on_error=False 时，出错时返回的指定值。
+            - None: 返回 None（默认）
+            - "error_log": 返回错误信息字符串
+            - 其他值: 返回指定的值
 
     Returns:
         按输入顺序排列的结果列表
+
+    Raises:
+        Exception: 当 raise_on_error=True 且函数执行出错时抛出异常
     """
-    return parallel_map(func, items, description, log_level, max_workers, progress_type, use_kwargs)
+    return parallel_map(func, items, description, log_level, max_workers, progress_type, unpack_args, unpack_kwargs, raise_on_error, error_return_value)
